@@ -102,7 +102,7 @@ class Domoticz(IPlugin):
 				log.msg("jsonreq.result :  %s" % (jsonreq['result']))
 				total = len (jsonreq['result'])
 				log.msg(" total    :  %s" % (total))
-				total = iter(total)	
+				total = range(total)	
 				for xx in total:
 					log.msg(" jsonreq - idx   :  %s" % (xx['idx']))
 					log.msg("   jsonreq - type   :  %s" % (xx['Type']))
